from pathlib import Path
from typing import List

from fastapi import APIRouter

from id_broker_common.kelvin import kelvin_session_kwargs, load_kelvin_session_kwargs
from ucsschool.apis.models import Plugin
from ucsschool.apis.utils import auth_manager, get_logger

from .routes.v1 import groups as groups_routes_v1, users as users_routes_v1

# the name of the plugin which will also determine the name of the resource
PLUGIN_NAME: str = "self_disclosure"
# the plugins current version. Not used for anything in the ucsschool-apis app
PLUGIN_VERSION: str = "1.0.0"
# the plugins tags:
PLUGIN_TAGS: List[str] = ["self_disclosure"]
# the router that will be mounted as the resource under the plugins name:
router: APIRouter = APIRouter()

PLUGIN_SETTINGS_FILE = Path("/etc/ucsschool/apis/id-broker/self-disclosure-api.json")


def setup():
    logger = get_logger()
    logger.info(f"Setup of {PLUGIN_NAME} with version {PLUGIN_VERSION}")
    kelvin_session_kwargs.update(load_kelvin_session_kwargs(PLUGIN_SETTINGS_FILE))
    auth_manager.tags[PLUGIN_NAME] = "Tag for all self disclosure API endpoints"


router.include_router(users_routes_v1.router, prefix="/v1/users")
router.include_router(groups_routes_v1.router, prefix="/v1/groups")

# This is the object that is referenced in the pyproject.toml as the plugin object:
SelfDisclosurePlugin = Plugin(PLUGIN_NAME, PLUGIN_VERSION, PLUGIN_TAGS, router, setup)
